==> xlniuxdata-vipgame-1.0.8-sources.jar: com/xunlei/niux/data/vipgame/vo/TriggerMessage.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Table;


/**
 * 触达系统消息配置
 * @author 李苏
 * @date 2013-08-17
 * @Descripter:
 */
@Table(tableName="triggermessage",pkFieldName="seqid",pkFieldAssign=false)
public class TriggerMessage {
	private Long seqid;
	private String gameId;
	private String serverId;
	private String userType;
	private String startTime;
	private String endTime;
	private Boolean triggerType;
	private String title;
	private String content;
	private String linkUrl;
	private Integer vipGrade;
	private String inputBy;
	private String inputTime;
	private String editBy;
	private String editTime;
	private Boolean isUser;
	private Integer locationType;
	private Integer displayOrder;
	
	public String getTitle() {
		return title;
	}
	public void setTitle(String title) {
		this.title = title;
	}	
	public Integer getDisplayOrder() {
		return displayOrder;
	}
	public void setDisplayOrder(Integer displayOrder) {
		this.displayOrder = displayOrder;
	}
	public Integer getLocationType() {
		return locationType;
	}
	public void setLocationType(Integer locationType) {
		this.locationType = locationType;
	}
	public Long getSeqid() {
		return seqid;
	}
	public void setSeqid(Long seqid) {
		this.seqid = seqid;
	}
	public String getGameId() {
		return gameId;
	}
	public void setGameId(String gameId) {
		this.gameId = gameId;
	}
	public String getServerId() {
		return serverId;
	}
	public void setServerId(String serverId) {
		this.serverId = serverId;
	}
	public String getUserType() {
		return userType;
	}
	public void setUserType(String userType) {
		this.userType = userType;
	}
	public String getStartTime() {
		return startTime;
	}
	public void setStartTime(String startTime) {
		this.startTime = startTime;
	}
	public String getEndTime() {
		return endTime;
	}
	public void setEndTime(String endTime) {
		this.endTime = endTime;
	}
	public Boolean getTriggerType() {
		return triggerType;
	}
	public void setTriggerType(Boolean triggerType) {
		this.triggerType = triggerType;
	}
	public String getContent() {
		return content;
	}
	public void setContent(String content) {
		this.content = content;
	}
	public String getLinkUrl() {
		return linkUrl;
	}
	public void setLinkUrl(String linkUrl) {
		this.linkUrl = linkUrl;
	}
	public Integer getVipGrade() {
		return vipGrade;
	}
	public void setVipGrade(Integer vipGrade) {
		this.vipGrade = vipGrade;
	}
	public String getInputBy() {
		return inputBy;
	}
	public void setInputBy(String inputBy) {
		this.inputBy = inputBy;
	}
	public String getInputTime() {
		return inputTime;
	}
	public void setInputTime(String inputTime) {
		this.inputTime = inputTime;
	}
	public String getEditBy() {
		return editBy;
	}
	public void setEditBy(String editBy) {
		this.editBy = editBy;
	}
	public String getEditTime() {
		return editTime;
	}
	public void setEditTime(String editTime) {
		this.editTime = editTime;
	}
	public Boolean getIsUser() {
		return isUser;
	}
	public void setIsUser(Boolean isUser) {
		this.isUser = isUser;
	}
}

==> xlniuxdata-vipgame-1.0.21-20150727.025259-5-sources.jar: com/xunlei/niux/data/vipgame/vo/TriggerMessage.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Table;


/**
 * 触达系统消息配置
 * @author 李苏
 * @date 2013-08-17
 * @Descripter:
 */
@Table(tableName="triggermessage",pkFieldName="seqid",pkFieldAssign=false)
public class TriggerMessage {
	private Long seqid;
	private String gameId;
	private String serverId;
	private String userType;
	private String startTime;
	private String endTime;
	private Boolean triggerType;
	private String title;
	private String content;
	private String linkUrl;
	private Integer vipGrade;
	private String inputBy;
	private String inputTime;
	private String editBy;
	private String editTime;
	private Boolean isUser;
	private Integer locationType;
	private Integer displayOrder;
    private String bgPicUrl;

    private Integer jinzuanLevel;
    private String neirong;

    public Integer getJinzuanLevel() {
        return jinzuanLevel;
    }

    public void setJinzuanLevel(Integer jinzuanLevel) {
        this.jinzuanLevel = jinzuanLevel;
    }

    public String getNeirong() {
        return neirong;
    }

    public void setNeirong(String neirong) {
        this.neirong = neirong;
    }

    public String getTitle() {
		return title;
	}
    public void setTitle(String title) {
		this.title = title;
	}	
	public Integer getDisplayOrder() {
		return displayOrder;
	}
	public void setDisplayOrder(Integer displayOrder) {
		this.displayOrder = displayOrder;
	}
	public Integer getLocationType() {
		return locationType;
	}
	public void setLocationType(Integer locationType) {
		this.locationType = locationType;
	}
	public Long getSeqid() {
		return seqid;
	}
	public void setSeqid(Long seqid) {
		this.seqid = seqid;
	}
	public String getGameId() {
		return gameId;
	}
	public void setGameId(String gameId) {
		this.gameId = gameId;
	}
	public String getServerId() {
		return serverId;
	}
	public void setServerId(String serverId) {
		this.serverId = serverId;
	}
	public String getUserType() {
		return userType;
	}
	public void setUserType(String userType) {
		this.userType = userType;
	}
	public String getStartTime() {
		return startTime;
	}
	public void setStartTime(String startTime) {
		this.startTime = startTime;
	}
	public String getEndTime() {
		return endTime;
	}
	public void setEndTime(String endTime) {
		this.endTime = endTime;
	}
	public Boolean getTriggerType() {
		return triggerType;
	}
	public void setTriggerType(Boolean triggerType) {
		this.triggerType = triggerType;
	}
	public String getContent() {
		return content;
	}
	public void setContent(String content) {
		this.content = content;
	}
	public String getLinkUrl() {
		return linkUrl;
	}
	public void setLinkUrl(String linkUrl) {
		this.linkUrl = linkUrl;
	}
	public Integer getVipGrade() {
		return vipGrade;
	}
	public void setVipGrade(Integer vipGrade) {
		this.vipGrade = vipGrade;
	}
	public String getInputBy() {
		return inputBy;
	}
	public void setInputBy(String inputBy) {
		this.inputBy = inputBy;
	}
	public String getInputTime() {
		return inputTime;
	}
	public void setInputTime(String inputTime) {
		this.inputTime = inputTime;
	}
	public String getEditBy() {
		return editBy;
	}
	public void setEditBy(String editBy) {
		this.editBy = editBy;
	}
	public String getEditTime() {
		return editTime;
	}
	public void setEditTime(String editTime) {
		this.editTime = editTime;
	}
	public Boolean getIsUser() {
		return isUser;
	}
	public void setIsUser(Boolean isUser) {
		this.isUser = isUser;
	}

    public String getBgPicUrl() {
        return bgPicUrl;
    }

    public void setBgPicUrl(String bgPicUrl) {
        this.bgPicUrl = bgPicUrl;
    }
}
